from .primes import lcm
from .primes import PrimeNumbers
from .primes import primesieve